@@ -2,7 +2,7 @@
 # This code is part of the MAterials Simulation Toolkit (MAST)
 # 
 # Maintainer: Tam Mayeshiba
-# Last updated: 2014-05-12 by Zhewen Song
+# Last updated: 2014-04-25
 ##############################################################
 from pymatgen.io.vaspio import Poscar
 from pymatgen.io.vaspio import Outcar
@@ -339,7 +339,8 @@ class VaspChecker(BaseChecker):
     def _vasp_incar_get_non_mast_keywords(self):
         """Get the non-VASP keywords and make a dictionary."""
         incar_dict=dict()
-        allowedpath = os.path.join(dirutil.get_mast_control_path(),
+        allowedpath = os.path.join(dirutil.get_mast_install_path(),
+                        'ingredients',
                         'programkeys','vasp_allowed_keywords.py')
         allowed_list = self._vasp_incar_get_allowed_keywords(allowedpath)
         for key, value in self.keywords['program_keys'].iteritems():
