@@ -12,6 +12,7 @@ EMAX
 EMIN
 ENCUT
 GGA
+I_CONSTRAINED_M
 IALGO
 IBRION
 ICHARG
@@ -20,11 +21,14 @@ INIWAV
 ISIF
 ISMEAR
 ISPIN
+ISPIND
 ISTART
 ISYM
 IWAVPR
 KBLOCK
 KPAR
+LAMBDA
+LAECHG
 LASYNC
 LCHARG
 LCLIMB
@@ -37,6 +41,7 @@ LDAUTYPE
 LDAUU
 LELF
 LMAXMIX
+LNONCOLLINEAR
 LORBIT
 LREAL
 LSCALAPACK
@@ -44,6 +49,7 @@ LSCALU
 LVHAR
 LVTOT
 LWAVE
+M_CONSTR
 MAGMOM
 NBANDS
 NBLK
