@@ -1,5 +1,8 @@
 from MAST.structopt.inp_out import read_xyz
-from MAST.structopt.generate.Individual import Individual
+try:
+    from MAST.structopt.generate.Individual import Individual
+except NameError:
+    print "NOTE: ASE is not installed. ASE must be installed for Structopt Individual.py to work correctly."
 from MAST.structopt.tools import find_top_layer
 
 def get_crystal_restart_indiv(Optimizer, indiv):
@@ -31,4 +34,4 @@ def get_crystal_restart_indiv(Optimizer, indiv):
     cells = Optimizer.cryscell
     crys.set_cell(cells)
     individ=Individual(crys)
-    return individ
\ No newline at end of file
+    return individ
