@@ -1,7 +1,7 @@
 ################################
 universe = vanilla
-executable = //home/mayeshiba/bin/submit_mast_wrapper.sh
-transfer_input_files =  //home/mayeshiba/bin/comparescratch.py
+executable = submit_mast_wrapper.sh
+transfer_input_files = comparescratch.py
 should_transfer_files = yes
 when_to_transfer_output = on_exit
 request_cpus = 1
@@ -16,7 +16,7 @@ error  = error
 getenv = true
 #+RequiresWholeMachine=true
 #+AccountingGroup = MSE_Morgan
-+WantFlocking = True
-+WantGlideIn = True
+#+WantFlocking = True
+#+WantGlideIn = True
 queue
 ################################
